Package: MatTransMix
Version: 0.1.18
Date: 2025-1-6
Title: Clustering with Matrix Gaussian and Matrix Transformation
        Mixture Models
Authors@R: c(person("Xuwen", "Zhu", role = c("aut", "cre"),
                    email = "xzhu20@ua.edu"),
             person("Volodymyr", "Melnykov", role = "aut"),
             person("Shuchismita", "Sarkar", role = "ctb"),
             person("Michael", "Hutt", role = c("ctb", "cph")),
             person("Stephen", "Moshier", role = c("ctb", "cph")),
             person("Rouben", "Rostamian", role = c("ctb", "cph")),
	     person("Carl Edward", "Rasmussen", role = c("ctb", "cph")),
	     person("Dianne", "Cook", role = c("ctb", "cph")))
Depends: R (>= 3.0.0)
LazyLoad: yes
LazyData: no
Description: Provides matrix Gaussian mixture models, matrix transformation mixture models and their model-based clustering results. The parsimonious models of the mean matrices and variance covariance matrices are implemented with a total of 196 variations. For more information, please check: Xuwen Zhu, Shuchismita Sarkar, and Volodymyr Melnykov (2021), "MatTransMix: an R package for matrix model-based clustering and parsimonious mixture modeling",  <doi:10.1007/s00357-021-09401-9>.
License: GPL (>= 2)
Imports: mvtnorm
Packaged: 2025-01-24 20:13:27 UTC; zhu
Author: Xuwen Zhu [aut, cre],
  Volodymyr Melnykov [aut],
  Shuchismita Sarkar [ctb],
  Michael Hutt [ctb, cph],
  Stephen Moshier [ctb, cph],
  Rouben Rostamian [ctb, cph],
  Carl Edward Rasmussen [ctb, cph],
  Dianne Cook [ctb, cph]
Maintainer: Xuwen Zhu <xzhu20@ua.edu>
NeedsCompilation: yes
Repository: CRAN
Date/Publication: 2025-01-29 17:20:08 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-25 20:13:24 UTC; unix
Archs: MatTransMix.so.dSYM
