useDynLib(MatTransMix, .registration = TRUE)
importFrom("stats", "var")
importFrom("mvtnorm", "pmvnorm")
importFrom("grDevices", "col2rgb", "rgb")
importFrom("graphics", "axis", "box", "legend", "lines", "par", "plot")

export(MatTrans.EM)
export(MatTrans.init)
export(print.EM)
export(summary.EM)
export(MatTrans.plot)


S3method(print, EM)
S3method(summary, EM)
